@@ -6,8 +6,7 @@ Description:
     General classes to represent a structured (scientific) document.
 '''
 
-#from nltk import word_tokenize
-from nltk.tokenize import word_tokenize
+from nltk import word_tokenize
 
 ##################################################################
 # NODE SUPER CLASS
